# Replication data file for 
#   Salehyan, Idean, Kristian Skrede Gleditsch, and David E. Cunningham. 
#   "Explaining External Support for Insurgent Groups", International Organization, 
#   forthcoming.
#
# Please note that the code requires the ROCR library from CRAN for the ROC plot,
#   and the MASS
#
# This version: 6 January 2011
# Please direct any questions to Kristian Skrede Gleditsch, Department of Government, 
#   University of Essex, Colchester CO4 3SQ, UK, email: ksg@essex.ac.uk

# Set working directory (modify to your local directory)
setwd("C:\\work\\work17\\sgc_transnational\\")

# Read main replication data
dyads <- read.table("sgc_io_data.txt",
    sep="\t",header=T,na=".",quote="")

# This generates table 1, i.e., the fully domestic models 
mod1 <- glm(supp1 ~ log(rgdpch) + cinc + I(POLITY>=6),
    data=dyads,na.action=na.omit,family=binomial)
mod2 <- glm(supp2 ~ log(rgdpch) + cinc + I(POLITY>=6),
    data=dyads,na.action=na.omit,family=binomial)
mod3 <- glm(supp3 ~ log(rgdpch) + cinc + I(POLITY>=6),
    data=dyads,na.action=na.omit,family=binomial)
summary(mod1)
summary(mod2)
summary(mod3)

# Supplementary code to write to file, extract LL, 
# and model LR \Chi^2, uncomment to run 
#
# write.table(round(summary(mod1)$coef[,1:3],3),
#    file="mod1.csv",sep=",")
# write.table(round(summary(mod2)$coef[,1:3],3),
#    file="mod2.csv",sep=",")
#write.table(round(summary(mod3)$coef[,1:3],3),
#    file="mod3.csv",sep=",")
# summary(mod1)$df.null+1
# summary(mod2)$df.null+1
# summary(mod3)$df.null+1
# logLik(mod1)
# logLik(mod2)
# logLik(mod3)
# summary(mod1)$null.deviance-summary(mod1)$deviance
# summary(mod2)$null.deviance-summary(mod2)$deviance
# summary(mod3)$null.deviance-summary(mod3)$deviance


# This generates table II, i.e., the transnational models

# collapse weak and parity
dyads$newstrength <- dyads$rs
dyads$newstrength[dyads$newstrength=="parity"] <- "weak"

# Model 4
mod4 <- glm(supp1 ~ as.factor(newstrength) + cl + gs + tk + tc + 
    I(noactors>1) + riv +  
    log(rgdpch) + cinc + I(POLITY>=6),
    data=dyads,na.action=na.omit,family=binomial, model=T)

# Model 5
mod5 <- glm(supp2 ~ as.factor(newstrength) + cl + gs + tk + tc + 
    I(noactors>1) + riv +  
    log(rgdpch) + cinc + I(POLITY>=6),
    data=dyads,na.action=na.omit,family=binomial)

# Model 6
mod6 <- glm(supp3 ~ as.factor(newstrength) + cl + gs + tk + tc + 
    I(noactors>1) + riv +  
    log(rgdpch) + cinc + I(POLITY>=6),
    data=dyads,na.action=na.omit,family=binomial)
summary(mod4)
summary(mod5)
summary(mod6)

# Supplementary code to write to file, extract LL, 
# and model LR \Chi^2, uncomment to run 
#
# summary(mod4)$df.null+1
# summary(mod5)$df.null+1
# summary(mod6)$df.null+1
# logLik(mod4)
# logLik(mod5)
# logLik(mod6)
# summary(mod4)$null.deviance-summary(mod4)$deviance
# summary(mod5)$null.deviance-summary(mod5)$deviance
# summary(mod6)$null.deviance-summary(mod6)$deviance

# LR joint test of the strength terms
c.mod4 <- update(mod4, . ~ . - as.factor(newstrength))
c.mod5 <- update(mod5, . ~ . - as.factor(newstrength))
c.mod6 <- update(mod6, . ~ . - as.factor(newstrength))
summary(c.mod4)$deviance-summary(mod4)$deviance
summary(c.mod5)$deviance-summary(mod5)$deviance
summary(c.mod6)$deviance-summary(mod6)$deviance

# This code generates the ROC plot 

# estimate a domestic null model
reg1.totalnull <- glm(supp1 ~ log(rgdpch) + cinc + I(POLITY>=6),
    data=dyads, subset=(!is.na(match(rownames(dyads),rownames(mod4$model)))),model=T,
    na.action=na.omit,family=binomial)

pdata <- mod4$model
pdata$basepred <- 1/(1+exp(-predict(reg1.totalnull)))
pdata$modpred <- 1/(1+exp(-predict(mod4)))

# Classification tables
table(pdata$supp1,pdata$basepred>=0.5)
table(pdata$supp1,pdata$modpred>=0.5)

library(ROCR)
pred <- prediction(pdata$basepred, pdata$supp1)
perf <- performance(pred, "tpr", "fpr" )
pred.mod <- prediction(pdata$modpred,pdata$supp1)
perf.mod <- performance(pred.mod, 'tpr', 'fpr')

# Code to write the plot to a postscript file, uncomment to run
# postscript("rocplot.eps")
plot(perf,main="ROC plot, support I",lty=8,cex=0.75,lwd=3)
abline(0,1,lty=3,col="grey",lwd=2)
plot(perf.mod, lty=1, lwd=3,col="dark grey",add=TRUE)
legend(-0.05, 1.05, c("Baseline domestic","W/ transnational ties"), col = c("black","dark grey"),
       cex=1, lty = c(8,1), bty="n")
# turn of device, if writing to a file
# dev.off()


# This section of the file provides code to replicate results mentioned
# but not reported in the paper
#
# Results using the Goertz and Diehl Rivalry data
dyads <- read.table("sgc_io_data2.txt",
    sep="\t",header=T,na=".",quote="")

mod4.gd <- glm(supp1 ~ I(newstrength=="much weaker") + I(newstrength=="strong") 
    + cl + gs + tk + tc + 
    I(noactors>1) + gdriv +  
    log(rgdpch) + cinc + I(POLITY>=6),
    data=dyads,na.action=na.omit,family=binomial, model=T)
summary(mod4.gd)

mod5.gd <- glm(supp2 ~ I(newstrength=="much weaker") + I(newstrength=="strong") + cl + gs + tk + tc + 
    I(noactors>1) + gdriv +  
    log(rgdpch) + cinc + I(POLITY>=6),
    data=dyads,na.action=na.omit,family=binomial)
summary(mod5.gd)

mod6.gd <- glm(supp3 ~ I(newstrength=="much weaker") + I(newstrength=="strong") + cl + gs + tk + tc + 
    I(noactors>1) + gdriv +  
    log(rgdpch) + cinc + I(POLITY>=6),
    data=dyads,na.action=na.omit,family=binomial)
summary(mod6.gd)


# Results for the negarive binomial regression of numbers of supporters
dyads <- read.table("sgc_io_data3.txt",
    sep="\t",header=T,na=".",quote="")

library(MASS)
dyads$nosups2 <- dyads$nosups
dyads$nosups2[dyads$supp1==0] <- 0

mod4.nb <- glm.nb(nosups2 ~ I(newstrength=="much weaker") + I(newstrength=="strong") 
    + cl + gs + tk + tc + 
    I(noactors>1) + riv +   
    log(rgdpch) + cinc + I(POLITY>=6),
    data=dyads,na.action=na.omit)
summary(mod4.nb)
logLik(mod4.nb)
logLik(update(mod4.nb, . ~ . - I(newstrength=="much weaker") - I(newstrength=="strong")))
